### Qt5 Libraries
%define lib_major_qt5 1
%define lib_name_qt5  %mklibname qt5keychain %{lib_major_qt5}
%define lib_dev_qt5   %mklibname qt5keychain -d
### Qt6 Libraries
%define lib_major_qt6 1
%define lib_name_qt6  %mklibname qt6keychain %{lib_major_qt6}
%define lib_dev_qt6   %mklibname qt6keychain -d

%bcond_with     qt5
%bcond_without  qt6

Name:           qtkeychain
Summary:        Platform-independent Qt API for storing passwords securely
Version:        0.14.2
Release:        %mkrel 1
License:        LGPLv2+
Group:          Graphical desktop/KDE
Url:            https://github.com/frankosterfeld/qtkeychain
Source0:        https://github.com/frankosterfeld/qtkeychain/archive/%version/%{name}-%{version}.tar.gz
### Qt5 Build dependencies
BuildRequires:  pkgconfig(Qt5Core)
BuildRequires:  pkgconfig(Qt5DBus)
BuildRequires:  pkgconfig(Qt5Help)
### Qt6 Build dependencies
BuildRequires:  cmake(Qt6Core)
BuildRequires:  cmake(Qt6DBus)
BuildRequires:  cmake(Qt6Help)

BuildRequires:  pkgconfig(libsecret-1)
BuildRequires:  cmake

%description
Platform-independent Qt API for storing passwords securely.

#------------------------------------------------------------------

%if %{with qt5}
%package -n     %{lib_name_qt5}
Summary:        Platform-independent Qt5 API for storing passwords securely
Group:          System/Libraries

%description -n %{lib_name_qt5}
Platform-independent Qt5 API for storing passwords securely.

%files -n %{lib_name_qt5}
%{_libdir}/libqt5keychain.so.%{lib_major_qt5}{,.*}
%{_libdir}/libqt5keychain.so.%{version}
%{_datadir}/qt5keychain/

#------------------------------------------------------------------

%package -n     %{lib_dev_qt5}
Summary:        Development tools for programs which will use the Qt5 keychain
Group:          Development/C
Requires:       %{lib_name_qt5} = %{version}
Provides:       qt5keychain-devel = %{version}-%{release}
Provides:       libqt5keychain-devel = %{version}-%{release}

%description -n %{lib_dev_qt5}
This package contains the header files and .so libraries
for developing qt5keychain.

%files -n %{lib_dev_qt5}
%doc ChangeLog ReadMe.md
%{_includedir}/qt5keychain/
%{_libdir}/libqt5keychain.so
%{_libdir}/cmake/Qt5Keychain/
%{_qt5_archdatadir}/mkspecs/modules/qt_Qt5Keychain.pri
%endif

#------------------------------------------------------------------

%if %{with qt6}
%package -n     %{lib_name_qt6}
Summary:        Platform-independent Qt6 API for storing passwords securely
Group:          System/Libraries

%description -n %{lib_name_qt6}
Platform-independent Qt6 API for storing passwords securely.

%files -n %{lib_name_qt6}
%license COPYING
%{_libdir}/libqt6keychain.so.%{lib_major_qt6}{,.*}
%{_libdir}/libqt6keychain.so.%{version}
%{_datadir}/qt6keychain/

#------------------------------------------------------------------

%package -n     %{lib_dev_qt6}
Summary:        Development tools for programs which will use the Qt6 keychain
Group:          Development/C
Requires:       %{lib_name_qt6} = %{version}
Provides:       qt6keychain-devel = %{version}-%{release}
Provides:       libqt6keychain-devel = %{version}-%{release}

%description -n %{lib_dev_qt6}
This package contains the header files and .so libraries
for developing qt6keychain.

%files -n %{lib_dev_qt6}
%doc ChangeLog ReadMe.md
%{_includedir}/qt6keychain/
%{_libdir}/libqt6keychain.so
%{_libdir}/cmake/Qt6Keychain/
%{_qt6_archdatadir}/mkspecs/modules/*.pri
%endif

#------------------------------------------------------------------

%prep
%autosetup -p1

%build
%if %{with qt5}
%define _vpath_builddir %{_target_platform}-qt5
%cmake_qt5 \
        -DBUILD_WITH_QT6:BOOL=OFF \
        -DLIBSECRET_SUPPORT=ON \
        -DECM_MKSPECS_INSTALL_DIR=%{_qt5_archdatadir}/mkspecs/modules

%cmake_build
%endif

%if %{with qt6}
%define _vpath_builddir %{_target_platform}-qt6
%cmake_qt6 \
        -DBUILD_WITH_QT6:BOOL=ON \
        -DLIBSECRET_SUPPORT=ON \
        -DECM_MKSPECS_INSTALL_DIR=%{_qt6_archdatadir}/mkspecs/modules

%cmake_build
%endif

%install
%if %{with qt5}
%define _vpath_builddir %{_target_platform}-qt5
%cmake_install
%endif

%if %{with qt6}
%define _vpath_builddir %{_target_platform}-qt6
%cmake_install
%endif


%changelog
* Fri Jan 19 2024 squidf <squid-f> 0.14.2-1.mga9
- Backport MGA9 for Qt6

* Wed Dec 20 2023 daviddavid <daviddavid> 0.14.2-1.mga10
+ Revision: 2020328
- new version: 0.14.2

* Tue Sep 12 2023 daviddavid <daviddavid> 0.14.1-1.mga10
+ Revision: 1986371
- new version: 0.14.1
- add Qt6 support
- prepare spec file for upcoming Qt6 support
- rename pkg to its original name (from qt5keychain to qtkeychain)

* Tue Sep 06 2022 papoteur <papoteur> 0.13.2-1.mga9
+ Revision: 1884522
- new 0.13.2

* Sun Apr 03 2022 umeabot <umeabot> 0.11.1-3.mga9
+ Revision: 1842187
- Mageia 9 Mass Rebuild

* Thu Dec 17 2020 umeabot <umeabot> 0.11.1-2.mga8
+ Revision: 1659562
- Rebuild for new Qt5

* Wed Sep 09 2020 daviddavid <daviddavid> 0.11.1-1.mga8
+ Revision: 1623761
- new version: 0.11.1

* Tue Feb 18 2020 umeabot <umeabot> 0.10.0-2.mga8
+ Revision: 1541258
- Mageia 8 Mass Rebuild
+ wally <wally>
- build with new cmake macros

* Sun Dec 22 2019 daviddavid <daviddavid> 0.10.0-1.mga8
+ Revision: 1469460
- new version: 0.10.0

* Mon Apr 01 2019 umeabot <umeabot> 0.9.1-2.mga7
+ Revision: 1384307
- Qt5 Rebuild

* Wed Oct 31 2018 daviddavid <daviddavid> 0.9.1-1.mga7
+ Revision: 1326838
- new version: 0.9.1

* Sun Sep 23 2018 umeabot <umeabot> 0.9.0-2.mga7
+ Revision: 1300689
- Mageia 7 Mass Rebuild

* Wed Aug 15 2018 daviddavid <daviddavid> 0.9.0-1.mga7
+ Revision: 1251700
- new version: 0.9.0

* Fri Aug 11 2017 daviddavid <daviddavid> 0.8.0-1.mga7
+ Revision: 1139749
- new version: 0.8.0

* Fri Sep 23 2016 daviddavid <daviddavid> 0.7.0-2.mga6
+ Revision: 1055598
- obsoletes old lib to ease upgrade mga5 -> mga6

* Thu Sep 08 2016 daviddavid <daviddavid> 0.7.0-1.mga6
+ Revision: 1050785
- new version: 0.7.0
- now libmajor is 1
- update description and summary

* Sat Feb 06 2016 umeabot <umeabot> 0.4-4.mga6
+ Revision: 940486
- Mageia 6 Mass Rebuild

* Wed Oct 15 2014 umeabot <umeabot> 0.4-3.mga5
+ Revision: 749900
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 0.4-2.mga5
+ Revision: 688533
- Mageia 5 Mass Rebuild

* Thu Sep 11 2014 colin <colin> 0.4-1.mga5
+ Revision: 674683
- More fixes for BuildRequires
- Fix BuildRequires
- New version: 0.4 (Qt5)
+ umeabot <umeabot>
- Mageia 4 Mass Rebuild
+ neoclust <neoclust>
- Do not requires qtkeychain package as it does not exist
- imported package qtkeychain

